#!/usr/bin/env python
# Copyright (c) 2014 Arista Networks, Inc.  All rights reserved.
# Arista Networks, Inc. Confidential and Proprietary.

import AsuPStore
from CliPlugin.AsuPStoreModel import ReloadHitlessWarningReason

class VxlanPStoreEventHandler( AsuPStore.PStoreEventHandler ):
   ''' When vxlan interface is configured,
   this configuration will block ASU2 hitless reload.
   '''
   def __init__( self, vxlanStatus ):
      AsuPStore.PStoreEventHandler.__init__( self )
      self.vxlanStatus_ = vxlanStatus

   def hitlessReloadSupported( self ):
      warningList, blockingList = [], []
      if self.vxlanStatus_ and len( self.vxlanStatus_ ) != 0:
         warningList.append( 
               ReloadHitlessWarningReason( reason='vxlanConfigured' ) )
      return ( warningList, blockingList )
   
def Plugin( ctx ):
   featureName = 'Vxlan'
   if ctx.opcode() == 'CheckHitlessReloadSupported':
      entityManager = ctx.entityManager()
      mg = entityManager.mountGroup()
      vxlanStatus = mg.mount( 'vxlan/status', 'Vxlan::VxlanStatusDir', 'r' )
      mg.close( blocking=True )
      ctx.registerAsuPStoreEventHandler( featureName,
                                         VxlanPStoreEventHandler( vxlanStatus ) )
   else:
      ctx.registerAsuPStoreEventHandler( featureName,
                                         VxlanPStoreEventHandler( None ) )
